$if(title-prefix)$$title-prefix$ - $endif$$pagetitle$
Author: $author-meta$
Date: $date-meta$

$for(author-meta)$ $endfor$ $if(date-meta)$ $endif$
$if(quotes)$
$endif$ $if(highlighting-css)$
$endif$ $for(css)$ $endfor$ $if(math)$ $math$ $endif$ $for(header-includes)$ $header-includes$ $endfor$
$for(include-before)$ $include-before$ $endfor$ $if(title)$

# $title$

$if(subtitle)$

# $subtitle$

$endif$ $for(author)$

## $author$

$endfor$ $if(date)$

### $date$

$endif$
$endif$

> “A beginning is the time for taking the most delicate care that the balances are correct.”

> – Frank Herbert, Dune

$if(toc)$
$toc$
$endif$ $body$ $for(include-after)$ $include-after$ $endfor$